@@ -148,7 +148,7 @@ class TestSMSTradeAPI(object):
                 ('cost', 'cost'),
                 ('message_id', 'message_id'),
                 ('count', 'count'),
-                ('reports', 'dir'),
+                ('reports', 'dlr'),
                 ('response', 'response')):
             setattr(api, attrname, True)
             request_params = {}
@@ -236,6 +236,16 @@ class TestSMSTradeAPI(object):
         assert result == {'00491717654321': {'status': smstrade.STATUS_OK}}
 
 
+@pytest.mark.usefixtures('cleandir')
+def test_empty_conffile():
+    with open('dummy.ini', 'w') as inifile:
+        inifile.write('')
+    conf = SafeConfigParser()
+    conf.read(['dummy.ini'])
+    smstrade.SMSTradeAPI(conf)
+    smstrade.SMSTradeBalanceAPI(conf)
+
+
 def test_hexstr():
     assert smstrade.hexstr('A0a0') == 'A0a0'
     with pytest.raises(argparse.ArgumentTypeError):
